@@ -44,10 +44,11 @@ class GSPeerConnectionBroadcaster:
             if self.gsdbs.credentials["stunenable"]:
                 self.rtconfiList.append(RTCIceServer(self.gsdbs.credentials["stunserver"]))
             if self.gsdbs.credentials["turnenable"]:
-                self.rtconfiList.append(RTCIceServer(urls=self.gsdbs.credentials["turnserver"],
-                                                     username=self.gsdbs.credentials["turnuser"],
-                                                     credential=self.gsdbs.credentials["turnpw"]
-                                                     ))
+                for turnserver in self.gsdbs.credentials["turnserver"]:
+                    self.rtconfiList.append(RTCIceServer(urls=turnserver,
+                                                         username=self.gsdbs.credentials["turnuser"],
+                                                         credential=self.gsdbs.credentials["turnpw"]
+                                                         ))
 
             camera.resolution = (self.gsdbs.credentials["hres"], self.gsdbs.credentials["vres"])
             camera.framerate = self.gsdbs.credentials["framerate"]
